---
test_data: TD_76_09_29_31
test_title: overlapped arg vals from diff arg types
---

Case: two different `arg_type`-s with some of their `arg_value`-s matching as strings.

For example, in `ServicePropName`, imagine value `amer.us` is both:
*   `geo_region`
*   `host_name`

If such `prop_name`-s used in a query for an object, it is important:
*   to consume args according to FS_76_29_13_28 args consumption priority
    (in the order of arg type list in FS_31_70_49_15 `search_control`)
*   not to consume the same token by more than one `prop_name`
